# Generated by roxygen2: do not edit by hand

export(abort_climate)
export(abort_column_not_found)
export(abort_model_error)
export(abort_validation)
export(air_pollution_do_analysis)
export(diarrhea_do_analysis)
export(install_INLA)
export(install_terra)
export(is_climate_error)
export(malaria_do_analysis)
export(run_descriptive_stats)
export(run_descriptive_stats_api)
export(suicides_heat_do_analysis)
export(temp_mortality_do_analysis)
export(wildfire_do_analysis)
import(dplyr)
importFrom(data.table,":=")
importFrom(dlnm,onebasis)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,grey)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,filled.contour)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(splines,bs)
importFrom(stats,aggregate)
importFrom(stats,approx)
importFrom(stats,ar)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dpois)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,quasipoisson)
importFrom(stats,resid)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,install.packages)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
